# Table of Contents

- [obsolescence-risk-management-plan-manage-mitigation](<./obsolescence-risk-management-plan-manage-mitigation.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 4: Plan and Manage Risk Mitigation Initiatives](<./Step-4-Plan-and-Manage-Risk-Mitigation-Initiatives.md>)
  - [Conduct a Risk Remediation Analysis](<./Step-4-Plan-and-Manage-Risk-Mitigation-Initiatives/Conduct-a-Risk-Remediation-Analysis.md>)
  - [Capture Risk Remediation Decisions](<./Step-4-Plan-and-Manage-Risk-Mitigation-Initiatives/Capture-Risk-Remediation-Decisions.md>)
  - [Establish Risk Dispensation Program](<./Step-4-Plan-and-Manage-Risk-Mitigation-Initiatives/Establish-Risk-Dispensation-Program.md>)
  - [Next Step](<./Step-4-Plan-and-Manage-Risk-Mitigation-Initiatives/Next-Step.md>)
